pub struct ArgumentsGetStringsRequest {
pub keys: Vec<String>,
}Fields
keys: Vec<String>Trait Implementations
Sourceimpl Clone for ArgumentsGetStringsRequest
impl Clone for ArgumentsGetStringsRequest
Sourcefn clone(&self) -> ArgumentsGetStringsRequest
fn clone(&self) -> ArgumentsGetStringsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentsGetStringsRequest
impl Debug for ArgumentsGetStringsRequest
Sourceimpl<___E> Encode<ArgumentsGetStringsRequest<'static>, ___E> for ArgumentsGetStringsRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<ArgumentsGetStringsRequest<'static>, ___E> for ArgumentsGetStringsRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetStringsRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetStringsRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ArgumentsGetStringsRequest<'static>, ___E> for &'a ArgumentsGetStringsRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<ArgumentsGetStringsRequest<'static>, ___E> for &'a ArgumentsGetStringsRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetStringsRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetStringsRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArgumentsGetStringsRequest<'static>>, ___E> for ArgumentsGetStringsRequestwhere
___E: Encoder + ?Sized,
ArgumentsGetStringsRequest: Encode<ArgumentsGetStringsRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArgumentsGetStringsRequest<'static>>, ___E> for ArgumentsGetStringsRequestwhere
___E: Encoder + ?Sized,
ArgumentsGetStringsRequest: Encode<ArgumentsGetStringsRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<ArgumentsGetStringsRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetStringsRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ArgumentsGetStringsRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetStringsRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetStringsRequest<'static>>, ___E> for &'a ArgumentsGetStringsRequestwhere
___E: Encoder + ?Sized,
&'a ArgumentsGetStringsRequest: Encode<ArgumentsGetStringsRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetStringsRequest<'static>>, ___E> for &'a ArgumentsGetStringsRequestwhere
___E: Encoder + ?Sized,
&'a ArgumentsGetStringsRequest: Encode<ArgumentsGetStringsRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a ArgumentsGetStringsRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetStringsRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ArgumentsGetStringsRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetStringsRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for ArgumentsGetStringsRequest
Sourceimpl<'de> FromWire<ArgumentsGetStringsRequest<'de>> for ArgumentsGetStringsRequest
impl<'de> FromWire<ArgumentsGetStringsRequest<'de>> for ArgumentsGetStringsRequest
Sourcefn from_wire(
wire: ArgumentsGetStringsRequest<'de>,
) -> ArgumentsGetStringsRequest
fn from_wire( wire: ArgumentsGetStringsRequest<'de>, ) -> ArgumentsGetStringsRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ArgumentsGetStringsRequest<'de>> for ArgumentsGetStringsRequest
impl<'de> FromWireRef<ArgumentsGetStringsRequest<'de>> for ArgumentsGetStringsRequest
Sourcefn from_wire_ref(
wire: &ArgumentsGetStringsRequest<'de>,
) -> ArgumentsGetStringsRequest
fn from_wire_ref( wire: &ArgumentsGetStringsRequest<'de>, ) -> ArgumentsGetStringsRequest
Converts the given reference to this type.
Sourceimpl Hash for ArgumentsGetStringsRequest
impl Hash for ArgumentsGetStringsRequest
Sourceimpl Ord for ArgumentsGetStringsRequest
impl Ord for ArgumentsGetStringsRequest
Sourcefn cmp(&self, other: &ArgumentsGetStringsRequest) -> Ordering
fn cmp(&self, other: &ArgumentsGetStringsRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArgumentsGetStringsRequest
impl PartialEq for ArgumentsGetStringsRequest
Sourcefn eq(&self, other: &ArgumentsGetStringsRequest) -> bool
fn eq(&self, other: &ArgumentsGetStringsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ArgumentsGetStringsRequest
impl PartialOrd for ArgumentsGetStringsRequest
impl StructuralPartialEq for ArgumentsGetStringsRequest