pub struct ArgumentsCollectResponse {
pub results: Vec<String>,
}Fields
results: Vec<String>Trait Implementations
Sourceimpl Clone for ArgumentsCollectResponse
impl Clone for ArgumentsCollectResponse
Sourcefn clone(&self) -> ArgumentsCollectResponse
fn clone(&self) -> ArgumentsCollectResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentsCollectResponse
impl Debug for ArgumentsCollectResponse
Sourceimpl<___E> Encode<ArgumentsCollectResponse<'static>, ___E> for ArgumentsCollectResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<ArgumentsCollectResponse<'static>, ___E> for ArgumentsCollectResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsCollectResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsCollectResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ArgumentsCollectResponse<'static>, ___E> for &'a ArgumentsCollectResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<ArgumentsCollectResponse<'static>, ___E> for &'a ArgumentsCollectResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsCollectResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsCollectResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArgumentsCollectResponse<'static>>, ___E> for ArgumentsCollectResponsewhere
___E: Encoder + ?Sized,
ArgumentsCollectResponse: Encode<ArgumentsCollectResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArgumentsCollectResponse<'static>>, ___E> for ArgumentsCollectResponsewhere
___E: Encoder + ?Sized,
ArgumentsCollectResponse: Encode<ArgumentsCollectResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<ArgumentsCollectResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsCollectResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ArgumentsCollectResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsCollectResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArgumentsCollectResponse<'static>>, ___E> for &'a ArgumentsCollectResponsewhere
___E: Encoder + ?Sized,
&'a ArgumentsCollectResponse: Encode<ArgumentsCollectResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ArgumentsCollectResponse<'static>>, ___E> for &'a ArgumentsCollectResponsewhere
___E: Encoder + ?Sized,
&'a ArgumentsCollectResponse: Encode<ArgumentsCollectResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a ArgumentsCollectResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsCollectResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ArgumentsCollectResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsCollectResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for ArgumentsCollectResponse
Sourceimpl<'de> FromWire<ArgumentsCollectResponse<'de>> for ArgumentsCollectResponse
impl<'de> FromWire<ArgumentsCollectResponse<'de>> for ArgumentsCollectResponse
Sourcefn from_wire(wire: ArgumentsCollectResponse<'de>) -> ArgumentsCollectResponse
fn from_wire(wire: ArgumentsCollectResponse<'de>) -> ArgumentsCollectResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ArgumentsCollectResponse<'de>> for ArgumentsCollectResponse
impl<'de> FromWireRef<ArgumentsCollectResponse<'de>> for ArgumentsCollectResponse
Sourcefn from_wire_ref(
wire: &ArgumentsCollectResponse<'de>,
) -> ArgumentsCollectResponse
fn from_wire_ref( wire: &ArgumentsCollectResponse<'de>, ) -> ArgumentsCollectResponse
Converts the given reference to this type.
Sourceimpl Hash for ArgumentsCollectResponse
impl Hash for ArgumentsCollectResponse
Sourceimpl Ord for ArgumentsCollectResponse
impl Ord for ArgumentsCollectResponse
Sourcefn cmp(&self, other: &ArgumentsCollectResponse) -> Ordering
fn cmp(&self, other: &ArgumentsCollectResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArgumentsCollectResponse
impl PartialEq for ArgumentsCollectResponse
Sourcefn eq(&self, other: &ArgumentsCollectResponse) -> bool
fn eq(&self, other: &ArgumentsCollectResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ArgumentsCollectResponse
impl PartialOrd for ArgumentsCollectResponse
impl StructuralPartialEq for ArgumentsCollectResponse