#[repr(C)]pub struct ArgumentsGetBoolResponse {
pub value: bool,
}Fields
value: boolTrait Implementations
Sourceimpl Clone for ArgumentsGetBoolResponse
impl Clone for ArgumentsGetBoolResponse
Sourcefn clone(&self) -> ArgumentsGetBoolResponse
fn clone(&self) -> ArgumentsGetBoolResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ArgumentsGetBoolResponse
Sourceimpl Debug for ArgumentsGetBoolResponse
impl Debug for ArgumentsGetBoolResponse
Sourceimpl<___E> Encode<ArgumentsGetBoolResponse, ___E> for ArgumentsGetBoolResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ArgumentsGetBoolResponse, ___E> for ArgumentsGetBoolResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ArgumentsGetBoolResponse, ArgumentsGetBoolResponse>
const COPY_OPTIMIZATION: CopyOptimization<ArgumentsGetBoolResponse, ArgumentsGetBoolResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<ArgumentsGetBoolResponse, ___E> for &'a ArgumentsGetBoolResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ArgumentsGetBoolResponse, ___E> for &'a ArgumentsGetBoolResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArgumentsGetBoolResponse>, ___E> for ArgumentsGetBoolResponse
impl<___E> EncodeOption<Box<'static, ArgumentsGetBoolResponse>, ___E> for ArgumentsGetBoolResponse
Sourcefn encode_option(
this: Option<ArgumentsGetBoolResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ArgumentsGetBoolResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetBoolResponse>, ___E> for &'a ArgumentsGetBoolResponse
impl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetBoolResponse>, ___E> for &'a ArgumentsGetBoolResponse
Sourcefn encode_option(
this: Option<&'a ArgumentsGetBoolResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ArgumentsGetBoolResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for ArgumentsGetBoolResponse
Sourceimpl FromWire<ArgumentsGetBoolResponse> for ArgumentsGetBoolResponse
impl FromWire<ArgumentsGetBoolResponse> for ArgumentsGetBoolResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ArgumentsGetBoolResponse, ArgumentsGetBoolResponse>
const COPY_OPTIMIZATION: CopyOptimization<ArgumentsGetBoolResponse, ArgumentsGetBoolResponse>
Sourcefn from_wire(wire: ArgumentsGetBoolResponse) -> ArgumentsGetBoolResponse
fn from_wire(wire: ArgumentsGetBoolResponse) -> ArgumentsGetBoolResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<ArgumentsGetBoolResponse> for ArgumentsGetBoolResponse
impl FromWireRef<ArgumentsGetBoolResponse> for ArgumentsGetBoolResponse
Sourcefn from_wire_ref(wire: &ArgumentsGetBoolResponse) -> ArgumentsGetBoolResponse
fn from_wire_ref(wire: &ArgumentsGetBoolResponse) -> ArgumentsGetBoolResponse
Converts the given reference to this type.
Sourceimpl Hash for ArgumentsGetBoolResponse
impl Hash for ArgumentsGetBoolResponse
Sourceimpl Ord for ArgumentsGetBoolResponse
impl Ord for ArgumentsGetBoolResponse
Sourcefn cmp(&self, other: &ArgumentsGetBoolResponse) -> Ordering
fn cmp(&self, other: &ArgumentsGetBoolResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArgumentsGetBoolResponse
impl PartialEq for ArgumentsGetBoolResponse
Sourcefn eq(&self, other: &ArgumentsGetBoolResponse) -> bool
fn eq(&self, other: &ArgumentsGetBoolResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ArgumentsGetBoolResponse
impl PartialOrd for ArgumentsGetBoolResponse
impl StructuralPartialEq for ArgumentsGetBoolResponse