pub struct ArgumentsGetBoolsResponse {
pub values: Vec<bool>,
}Fields
values: Vec<bool>Trait Implementations
Sourceimpl Clone for ArgumentsGetBoolsResponse
impl Clone for ArgumentsGetBoolsResponse
Sourcefn clone(&self) -> ArgumentsGetBoolsResponse
fn clone(&self) -> ArgumentsGetBoolsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentsGetBoolsResponse
impl Debug for ArgumentsGetBoolsResponse
Sourceimpl<___E> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for ArgumentsGetBoolsResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for ArgumentsGetBoolsResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for &'a ArgumentsGetBoolsResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for &'a ArgumentsGetBoolsResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArgumentsGetBoolsResponse<'static>>, ___E> for ArgumentsGetBoolsResponsewhere
___E: Encoder + ?Sized,
ArgumentsGetBoolsResponse: Encode<ArgumentsGetBoolsResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArgumentsGetBoolsResponse<'static>>, ___E> for ArgumentsGetBoolsResponsewhere
___E: Encoder + ?Sized,
ArgumentsGetBoolsResponse: Encode<ArgumentsGetBoolsResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<ArgumentsGetBoolsResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolsResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ArgumentsGetBoolsResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolsResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetBoolsResponse<'static>>, ___E> for &'a ArgumentsGetBoolsResponsewhere
___E: Encoder + ?Sized,
&'a ArgumentsGetBoolsResponse: Encode<ArgumentsGetBoolsResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetBoolsResponse<'static>>, ___E> for &'a ArgumentsGetBoolsResponsewhere
___E: Encoder + ?Sized,
&'a ArgumentsGetBoolsResponse: Encode<ArgumentsGetBoolsResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a ArgumentsGetBoolsResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolsResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ArgumentsGetBoolsResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetBoolsResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for ArgumentsGetBoolsResponse
Sourceimpl<'de> FromWire<ArgumentsGetBoolsResponse<'de>> for ArgumentsGetBoolsResponse
impl<'de> FromWire<ArgumentsGetBoolsResponse<'de>> for ArgumentsGetBoolsResponse
Sourcefn from_wire(wire: ArgumentsGetBoolsResponse<'de>) -> ArgumentsGetBoolsResponse
fn from_wire(wire: ArgumentsGetBoolsResponse<'de>) -> ArgumentsGetBoolsResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ArgumentsGetBoolsResponse<'de>> for ArgumentsGetBoolsResponse
impl<'de> FromWireRef<ArgumentsGetBoolsResponse<'de>> for ArgumentsGetBoolsResponse
Sourcefn from_wire_ref(
wire: &ArgumentsGetBoolsResponse<'de>,
) -> ArgumentsGetBoolsResponse
fn from_wire_ref( wire: &ArgumentsGetBoolsResponse<'de>, ) -> ArgumentsGetBoolsResponse
Converts the given reference to this type.
Sourceimpl Hash for ArgumentsGetBoolsResponse
impl Hash for ArgumentsGetBoolsResponse
Sourceimpl Ord for ArgumentsGetBoolsResponse
impl Ord for ArgumentsGetBoolsResponse
Sourcefn cmp(&self, other: &ArgumentsGetBoolsResponse) -> Ordering
fn cmp(&self, other: &ArgumentsGetBoolsResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArgumentsGetBoolsResponse
impl PartialEq for ArgumentsGetBoolsResponse
Sourcefn eq(&self, other: &ArgumentsGetBoolsResponse) -> bool
fn eq(&self, other: &ArgumentsGetBoolsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ArgumentsGetBoolsResponse
impl PartialOrd for ArgumentsGetBoolsResponse
impl StructuralPartialEq for ArgumentsGetBoolsResponse