#[repr(C)]pub struct BootfsFileVmo {
pub offset: u32,
pub contents: Vmo,
}Expand description
Refers to a VMO that has been created from the big bootfs VMO.
Fields
offset: u32contents: VmoTrait Implementations
Sourceimpl Debug for BootfsFileVmo
impl Debug for BootfsFileVmo
Sourceimpl<___E> Encode<BootfsFileVmo, ___E> for BootfsFileVmowhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<BootfsFileVmo, ___E> for BootfsFileVmowhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, BootfsFileVmo>
const COPY_OPTIMIZATION: CopyOptimization<Self, BootfsFileVmo>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BootfsFileVmo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BootfsFileVmo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, BootfsFileVmo>, ___E> for BootfsFileVmo
impl<___E> EncodeOption<Box<'static, BootfsFileVmo>, ___E> for BootfsFileVmo
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BootfsFileVmo>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BootfsFileVmo>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<BootfsFileVmo> for BootfsFileVmo
impl FromWire<BootfsFileVmo> for BootfsFileVmo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BootfsFileVmo, Self>
const COPY_OPTIMIZATION: CopyOptimization<BootfsFileVmo, Self>
Sourcefn from_wire(wire: BootfsFileVmo) -> Self
fn from_wire(wire: BootfsFileVmo) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for BootfsFileVmo
impl PartialEq for BootfsFileVmo
Sourcefn eq(&self, other: &BootfsFileVmo) -> bool
fn eq(&self, other: &BootfsFileVmo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BootfsFileVmo