pub struct ItemsGet2Response {
pub retrieved_items: Vec<RetrievedItems>,
}Fields
retrieved_items: Vec<RetrievedItems>Trait Implementations
Sourceimpl Debug for ItemsGet2Response
impl Debug for ItemsGet2Response
Sourceimpl<___E> Encode<ItemsGet2Response<'static>, ___E> for ItemsGet2Responsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<ItemsGet2Response<'static>, ___E> for ItemsGet2Responsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGet2Response<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGet2Response<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ItemsGet2Response<'static>>, ___E> for ItemsGet2Response
impl<___E> EncodeOption<Box<'static, ItemsGet2Response<'static>>, ___E> for ItemsGet2Response
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ItemsGet2Response<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ItemsGet2Response<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ItemsGet2Response<'de>> for ItemsGet2Response
impl<'de> FromWire<ItemsGet2Response<'de>> for ItemsGet2Response
Sourcefn from_wire(wire: ItemsGet2Response<'de>) -> Self
fn from_wire(wire: ItemsGet2Response<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for ItemsGet2Response
impl PartialEq for ItemsGet2Response
Sourcefn eq(&self, other: &ItemsGet2Response) -> bool
fn eq(&self, other: &ItemsGet2Response) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ItemsGet2Response