#[repr(C)]pub struct ItemsGetResponse {
pub payload: Option<Vmo>,
pub length: u32,
}Fields
payload: Option<Vmo>length: u32Trait Implementations
Sourceimpl Debug for ItemsGetResponse
impl Debug for ItemsGetResponse
Sourceimpl<___E> Encode<ItemsGetResponse, ___E> for ItemsGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ItemsGetResponse, ___E> for ItemsGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ItemsGetResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ItemsGetResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ItemsGetResponse>, ___E> for ItemsGetResponse
impl<___E> EncodeOption<Box<'static, ItemsGetResponse>, ___E> for ItemsGetResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ItemsGetResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ItemsGetResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ItemsGetResponse> for ItemsGetResponse
impl FromWire<ItemsGetResponse> for ItemsGetResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ItemsGetResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ItemsGetResponse, Self>
Sourcefn from_wire(wire: ItemsGetResponse) -> Self
fn from_wire(wire: ItemsGetResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ItemsGetResponse
impl PartialEq for ItemsGetResponse
Sourcefn eq(&self, other: &ItemsGetResponse) -> bool
fn eq(&self, other: &ItemsGetResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ItemsGetResponse