#[repr(C)]pub struct ReadOnlyLogGetResponse {
pub log: DebugLog,
}Fields
log: DebugLogTrait Implementations
Sourceimpl Debug for ReadOnlyLogGetResponse
impl Debug for ReadOnlyLogGetResponse
Sourceimpl<___E> Encode<ReadOnlyLogGetResponse, ___E> for ReadOnlyLogGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ReadOnlyLogGetResponse, ___E> for ReadOnlyLogGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ReadOnlyLogGetResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ReadOnlyLogGetResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ReadOnlyLogGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ReadOnlyLogGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ReadOnlyLogGetResponse>, ___E> for ReadOnlyLogGetResponse
impl<___E> EncodeOption<Box<'static, ReadOnlyLogGetResponse>, ___E> for ReadOnlyLogGetResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ReadOnlyLogGetResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ReadOnlyLogGetResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ReadOnlyLogGetResponse> for ReadOnlyLogGetResponse
impl FromWire<ReadOnlyLogGetResponse> for ReadOnlyLogGetResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ReadOnlyLogGetResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ReadOnlyLogGetResponse, Self>
Sourcefn from_wire(wire: ReadOnlyLogGetResponse) -> Self
fn from_wire(wire: ReadOnlyLogGetResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ReadOnlyLogGetResponse
impl PartialEq for ReadOnlyLogGetResponse
Sourcefn eq(&self, other: &ReadOnlyLogGetResponse) -> bool
fn eq(&self, other: &ReadOnlyLogGetResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReadOnlyLogGetResponse