#[repr(C)]pub struct SvcStashStoreRequest {
pub svc_endpoint: ServerEnd<Directory, Channel>,
}Fields
svc_endpoint: ServerEnd<Directory, Channel>Trait Implementations
Sourceimpl Debug for SvcStashStoreRequest
impl Debug for SvcStashStoreRequest
Sourceimpl<___E> Encode<SvcStashStoreRequest, ___E> for SvcStashStoreRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SvcStashStoreRequest, ___E> for SvcStashStoreRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SvcStashStoreRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, SvcStashStoreRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SvcStashStoreRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SvcStashStoreRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SvcStashStoreRequest>, ___E> for SvcStashStoreRequest
impl<___E> EncodeOption<Box<'static, SvcStashStoreRequest>, ___E> for SvcStashStoreRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SvcStashStoreRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SvcStashStoreRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SvcStashStoreRequest> for SvcStashStoreRequest
impl FromWire<SvcStashStoreRequest> for SvcStashStoreRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SvcStashStoreRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<SvcStashStoreRequest, Self>
Sourcefn from_wire(wire: SvcStashStoreRequest) -> Self
fn from_wire(wire: SvcStashStoreRequest) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for SvcStashStoreRequest
impl PartialEq for SvcStashStoreRequest
Sourcefn eq(&self, other: &SvcStashStoreRequest) -> bool
fn eq(&self, other: &SvcStashStoreRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SvcStashStoreRequest