#[repr(C)]pub struct UserbootPostStashSvcRequest {
pub stash_svc_endpoint: ServerEnd<SvcStash, Channel>,
}Fields
stash_svc_endpoint: ServerEnd<SvcStash, Channel>Trait Implementations
Sourceimpl Debug for UserbootPostStashSvcRequest
impl Debug for UserbootPostStashSvcRequest
Sourceimpl<___E> Encode<UserbootPostStashSvcRequest, ___E> for UserbootPostStashSvcRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<UserbootPostStashSvcRequest, ___E> for UserbootPostStashSvcRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, UserbootPostStashSvcRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, UserbootPostStashSvcRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UserbootPostStashSvcRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UserbootPostStashSvcRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, UserbootPostStashSvcRequest>, ___E> for UserbootPostStashSvcRequestwhere
___E: Encoder + ?Sized,
UserbootPostStashSvcRequest: Encode<UserbootPostStashSvcRequest, ___E>,
impl<___E> EncodeOption<Box<'static, UserbootPostStashSvcRequest>, ___E> for UserbootPostStashSvcRequestwhere
___E: Encoder + ?Sized,
UserbootPostStashSvcRequest: Encode<UserbootPostStashSvcRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UserbootPostStashSvcRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UserbootPostStashSvcRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<UserbootPostStashSvcRequest> for UserbootPostStashSvcRequest
impl FromWire<UserbootPostStashSvcRequest> for UserbootPostStashSvcRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<UserbootPostStashSvcRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<UserbootPostStashSvcRequest, Self>
Sourcefn from_wire(wire: UserbootPostStashSvcRequest) -> Self
fn from_wire(wire: UserbootPostStashSvcRequest) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for UserbootPostStashSvcRequest
impl PartialEq for UserbootPostStashSvcRequest
Sourcefn eq(&self, other: &UserbootPostStashSvcRequest) -> bool
fn eq(&self, other: &UserbootPostStashSvcRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UserbootPostStashSvcRequest