#[repr(C)]pub struct WriteOnlyLogGetResponse {
pub log: DebugLog,
}Fields
log: DebugLogTrait Implementations
Sourceimpl Debug for WriteOnlyLogGetResponse
impl Debug for WriteOnlyLogGetResponse
Sourceimpl<___E> Encode<WriteOnlyLogGetResponse, ___E> for WriteOnlyLogGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<WriteOnlyLogGetResponse, ___E> for WriteOnlyLogGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, WriteOnlyLogGetResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, WriteOnlyLogGetResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WriteOnlyLogGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WriteOnlyLogGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, WriteOnlyLogGetResponse>, ___E> for WriteOnlyLogGetResponse
impl<___E> EncodeOption<Box<'static, WriteOnlyLogGetResponse>, ___E> for WriteOnlyLogGetResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WriteOnlyLogGetResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WriteOnlyLogGetResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<WriteOnlyLogGetResponse> for WriteOnlyLogGetResponse
impl FromWire<WriteOnlyLogGetResponse> for WriteOnlyLogGetResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WriteOnlyLogGetResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<WriteOnlyLogGetResponse, Self>
Sourcefn from_wire(wire: WriteOnlyLogGetResponse) -> Self
fn from_wire(wire: WriteOnlyLogGetResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for WriteOnlyLogGetResponse
impl PartialEq for WriteOnlyLogGetResponse
Sourcefn eq(&self, other: &WriteOnlyLogGetResponse) -> bool
fn eq(&self, other: &WriteOnlyLogGetResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WriteOnlyLogGetResponse