pub struct ArgumentsGetStringResponse {
pub value: Option<String>,
}Fields
value: Option<String>Trait Implementations
Sourceimpl Clone for ArgumentsGetStringResponse
impl Clone for ArgumentsGetStringResponse
Sourcefn clone(&self) -> ArgumentsGetStringResponse
fn clone(&self) -> ArgumentsGetStringResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentsGetStringResponse
impl Debug for ArgumentsGetStringResponse
Sourceimpl<___E> Encode<ArgumentsGetStringResponse<'static>, ___E> for ArgumentsGetStringResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<ArgumentsGetStringResponse<'static>, ___E> for ArgumentsGetStringResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetStringResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetStringResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ArgumentsGetStringResponse<'static>, ___E> for &'a ArgumentsGetStringResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<ArgumentsGetStringResponse<'static>, ___E> for &'a ArgumentsGetStringResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetStringResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetStringResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ArgumentsGetStringResponse<'static>>, ___E> for ArgumentsGetStringResponsewhere
___E: Encoder + ?Sized,
ArgumentsGetStringResponse: Encode<ArgumentsGetStringResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ArgumentsGetStringResponse<'static>>, ___E> for ArgumentsGetStringResponsewhere
___E: Encoder + ?Sized,
ArgumentsGetStringResponse: Encode<ArgumentsGetStringResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<ArgumentsGetStringResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetStringResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ArgumentsGetStringResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetStringResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetStringResponse<'static>>, ___E> for &'a ArgumentsGetStringResponsewhere
___E: Encoder + ?Sized,
&'a ArgumentsGetStringResponse: Encode<ArgumentsGetStringResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ArgumentsGetStringResponse<'static>>, ___E> for &'a ArgumentsGetStringResponsewhere
___E: Encoder + ?Sized,
&'a ArgumentsGetStringResponse: Encode<ArgumentsGetStringResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a ArgumentsGetStringResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArgumentsGetStringResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ArgumentsGetStringResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArgumentsGetStringResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for ArgumentsGetStringResponse
Sourceimpl<'de> FromWire<ArgumentsGetStringResponse<'de>> for ArgumentsGetStringResponse
impl<'de> FromWire<ArgumentsGetStringResponse<'de>> for ArgumentsGetStringResponse
Sourcefn from_wire(
wire: ArgumentsGetStringResponse<'de>,
) -> ArgumentsGetStringResponse
fn from_wire( wire: ArgumentsGetStringResponse<'de>, ) -> ArgumentsGetStringResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ArgumentsGetStringResponse<'de>> for ArgumentsGetStringResponse
impl<'de> FromWireRef<ArgumentsGetStringResponse<'de>> for ArgumentsGetStringResponse
Sourcefn from_wire_ref(
wire: &ArgumentsGetStringResponse<'de>,
) -> ArgumentsGetStringResponse
fn from_wire_ref( wire: &ArgumentsGetStringResponse<'de>, ) -> ArgumentsGetStringResponse
Converts the given reference to this type.
Sourceimpl Hash for ArgumentsGetStringResponse
impl Hash for ArgumentsGetStringResponse
Sourceimpl Ord for ArgumentsGetStringResponse
impl Ord for ArgumentsGetStringResponse
Sourcefn cmp(&self, other: &ArgumentsGetStringResponse) -> Ordering
fn cmp(&self, other: &ArgumentsGetStringResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArgumentsGetStringResponse
impl PartialEq for ArgumentsGetStringResponse
Sourcefn eq(&self, other: &ArgumentsGetStringResponse) -> bool
fn eq(&self, other: &ArgumentsGetStringResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ArgumentsGetStringResponse
impl PartialOrd for ArgumentsGetStringResponse
impl StructuralPartialEq for ArgumentsGetStringResponse