pub struct Userboot;Expand description
The type corresponding to the Userboot protocol.
Protocol for communication between userboot and the process booted by userboot.
The userboot process will act as a client, pipelining requests containing information and/or handles that might be useful for the booted process. The booted process, or whoever processes the server endpoint of this protocol, will then process the pipelined requests from userboot.
TODO(https://fxbug.dev/354275371): Move handles not participating in the bootstrap process to this protocol.