FactoryItemsServerHandler

Trait FactoryItemsServerHandler 

pub trait FactoryItemsServerHandler<___T: Transport = Channel> {
    // Required method
    fn get(
        &mut self,
        request: Request<Get, ___T>,
        responder: Responder<Get, ___T>,
    ) -> impl Future<Output = ()> + Send;
}
A server handler for the FactoryItems protocol.

See FactoryItems for more details.

Required Methods

fn get( &mut self, request: Request<Get, ___T>, responder: Responder<Get, ___T>, ) -> impl Future<Output = ()> + Send

Gets a payload for a ZBI_TYPE_STORAGE_BOOTFS_FACTORY boot item with extra field set to extra.

NOTE: We return the length of the item, as VMOs must be page-aligned.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors