SvcStashProviderLocalServerHandler

Trait SvcStashProviderLocalServerHandler 

pub trait SvcStashProviderLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn get(
        &mut self,
        responder: Responder<Get, ___T>,
    ) -> impl Future<Output = ()>;
}
A server handler for the SvcStashProvider protocol.

See SvcStashProvider for more details.

Required Methods

fn get(&mut self, responder: Responder<Get, ___T>) -> impl Future<Output = ()>

Get the SvcStash server endpoint.

There is at most one instance for the system, meaning only the first caller may consume the handle.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<___H, ___T> SvcStashProviderLocalServerHandler<___T> for Local<___H>
where ___H: SvcStashProviderServerHandler<___T>, ___T: Transport,

Source

async fn get(&mut self, responder: Responder<Get, ___T>)

Implementors