SvcStashProviderServerHandler

Trait SvcStashProviderServerHandler 

pub trait SvcStashProviderServerHandler<___T: Transport = Channel> {
    // Required method
    fn get(
        &mut self,
        responder: Responder<Get, ___T>,
    ) -> impl Future<Output = ()> + Send;
}
A server handler for the SvcStashProvider protocol.

See SvcStashProvider for more details.

Required Methods

fn get( &mut self, responder: Responder<Get, ___T>, ) -> impl Future<Output = ()> + Send

Get the SvcStash server endpoint.

There is at most one instance for the system, meaning only the first caller may consume the handle.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors