UserbootLocalServerHandler

Trait UserbootLocalServerHandler 

pub trait UserbootLocalServerHandler<___T: Transport = Channel> {
    // Required methods
    fn post_bootfs_files(
        &mut self,
        request: Request<PostBootfsFiles, ___T>,
    ) -> impl Future<Output = ()>;
    fn post_stash_svc(
        &mut self,
        request: Request<PostStashSvc, ___T>,
    ) -> impl Future<Output = ()>;
}
A server handler for the Userboot protocol.

See Userboot for more details.

Required Methods

fn post_bootfs_files( &mut self, request: Request<PostBootfsFiles, ___T>, ) -> impl Future<Output = ()>

Posts a set of BootfsFileVmo that were used for launching the userboot.next= program and are no longer available in the big BootfsVmo.

Messages will only become available after the Userboot protocol client end (userboot’s handle) has been closed.

fn post_stash_svc( &mut self, request: Request<PostStashSvc, ___T>, ) -> impl Future<Output = ()>

Posts svc_stash server endpoint. For more information refer to fuchsia.boot.SvcStash.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<___H, ___T> UserbootLocalServerHandler<___T> for Local<___H>
where ___H: UserbootServerHandler<___T>, ___T: Transport,

Source

async fn post_bootfs_files(&mut self, request: Request<PostBootfsFiles, ___T>)

Source

async fn post_stash_svc(&mut self, request: Request<PostStashSvc, ___T>)

Implementors