#[repr(C)]pub struct ArgumentsGetBoolResponse {
pub value: bool,
}Expand description
The wire type corresponding to ArgumentsGetBoolResponse.
Fields
value: boolTrait Implementations
Sourceimpl Clone for ArgumentsGetBoolResponse
impl Clone for ArgumentsGetBoolResponse
Sourcefn clone(&self) -> ArgumentsGetBoolResponse
fn clone(&self) -> ArgumentsGetBoolResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ArgumentsGetBoolResponse
impl Constrained for ArgumentsGetBoolResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ArgumentsGetBoolResponse>,
_: <ArgumentsGetBoolResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ArgumentsGetBoolResponse>, _: <ArgumentsGetBoolResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for ArgumentsGetBoolResponse
impl Debug for ArgumentsGetBoolResponse
Sourceimpl<___D> Decode<___D> for ArgumentsGetBoolResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ArgumentsGetBoolResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<ArgumentsGetBoolResponse, ___E> for ArgumentsGetBoolResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ArgumentsGetBoolResponse, ___E> for ArgumentsGetBoolResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ArgumentsGetBoolResponse, ArgumentsGetBoolResponse>
const COPY_OPTIMIZATION: CopyOptimization<ArgumentsGetBoolResponse, ArgumentsGetBoolResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<ArgumentsGetBoolResponse, ___E> for &'a ArgumentsGetBoolResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ArgumentsGetBoolResponse, ___E> for &'a ArgumentsGetBoolResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<ArgumentsGetBoolResponse, ___E> for ArgumentsGetBoolResponse<T0>
impl<___E, T0> Encode<ArgumentsGetBoolResponse, ___E> for ArgumentsGetBoolResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ArgumentsGetBoolResponse> for ArgumentsGetBoolResponse
impl FromWire<ArgumentsGetBoolResponse> for ArgumentsGetBoolResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ArgumentsGetBoolResponse, ArgumentsGetBoolResponse>
const COPY_OPTIMIZATION: CopyOptimization<ArgumentsGetBoolResponse, ArgumentsGetBoolResponse>
Sourcefn from_wire(wire: ArgumentsGetBoolResponse) -> ArgumentsGetBoolResponse
fn from_wire(wire: ArgumentsGetBoolResponse) -> ArgumentsGetBoolResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<ArgumentsGetBoolResponse> for ArgumentsGetBoolResponse
impl FromWireRef<ArgumentsGetBoolResponse> for ArgumentsGetBoolResponse
Sourcefn from_wire_ref(wire: &ArgumentsGetBoolResponse) -> ArgumentsGetBoolResponse
fn from_wire_ref(wire: &ArgumentsGetBoolResponse) -> ArgumentsGetBoolResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for ArgumentsGetBoolResponse
impl IntoNatural for ArgumentsGetBoolResponse
Sourcetype Natural = ArgumentsGetBoolResponse
type Natural = ArgumentsGetBoolResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ArgumentsGetBoolResponse
impl Wire for ArgumentsGetBoolResponse
Sourcetype Narrowed<'de> = ArgumentsGetBoolResponse
type Narrowed<'de> = ArgumentsGetBoolResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ArgumentsGetBoolResponse>)
fn zero_padding(out_: &mut MaybeUninit<ArgumentsGetBoolResponse>)
Writes zeroes to the padding for this type, if any.