#[repr(C)]pub struct ArgumentsGetBoolsResponse<'de> {
pub values: Vector<'de, bool>,
}Expand description
The wire type corresponding to ArgumentsGetBoolsResponse.
Fields
values: Vector<'de, bool>Trait Implementations
Sourceimpl Constrained for ArgumentsGetBoolsResponse<'_>
impl Constrained for ArgumentsGetBoolsResponse<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ArgumentsGetBoolsResponse<'_>>,
_: <ArgumentsGetBoolsResponse<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ArgumentsGetBoolsResponse<'_>>, _: <ArgumentsGetBoolsResponse<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for ArgumentsGetBoolsResponse<'de>
impl<'de> Debug for ArgumentsGetBoolsResponse<'de>
Sourceimpl<'de, ___D> Decode<___D> for ArgumentsGetBoolsResponse<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for ArgumentsGetBoolsResponse<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<___E> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for ArgumentsGetBoolsResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for ArgumentsGetBoolsResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for &'a ArgumentsGetBoolsResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for &'a ArgumentsGetBoolsResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for ArgumentsGetBoolsResponse<T0>
impl<___E, T0> Encode<ArgumentsGetBoolsResponse<'static>, ___E> for ArgumentsGetBoolsResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<ArgumentsGetBoolsResponse<'de>> for ArgumentsGetBoolsResponse
impl<'de> FromWire<ArgumentsGetBoolsResponse<'de>> for ArgumentsGetBoolsResponse
Sourcefn from_wire(wire: ArgumentsGetBoolsResponse<'de>) -> ArgumentsGetBoolsResponse
fn from_wire(wire: ArgumentsGetBoolsResponse<'de>) -> ArgumentsGetBoolsResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ArgumentsGetBoolsResponse<'de>> for ArgumentsGetBoolsResponse
impl<'de> FromWireRef<ArgumentsGetBoolsResponse<'de>> for ArgumentsGetBoolsResponse
Sourcefn from_wire_ref(
wire: &ArgumentsGetBoolsResponse<'de>,
) -> ArgumentsGetBoolsResponse
fn from_wire_ref( wire: &ArgumentsGetBoolsResponse<'de>, ) -> ArgumentsGetBoolsResponse
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for ArgumentsGetBoolsResponse<'de>
impl<'de> IntoNatural for ArgumentsGetBoolsResponse<'de>
Sourcetype Natural = ArgumentsGetBoolsResponse
type Natural = ArgumentsGetBoolsResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ArgumentsGetBoolsResponse<'static>
impl Wire for ArgumentsGetBoolsResponse<'static>
Sourcetype Narrowed<'de> = ArgumentsGetBoolsResponse<'de>
type Narrowed<'de> = ArgumentsGetBoolsResponse<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>)
fn zero_padding(out_: &mut MaybeUninit<ArgumentsGetBoolsResponse<'static>>)
Writes zeroes to the padding for this type, if any.