#[repr(C)]pub struct BootfsFileVmo {
pub offset: Uint32,
pub contents: Vmo,
}Expand description
The wire type corresponding to BootfsFileVmo.
Fields
offset: Uint32contents: VmoTrait Implementations
Sourceimpl Constrained for BootfsFileVmo
impl Constrained for BootfsFileVmo
Sourceimpl Debug for BootfsFileVmo
impl Debug for BootfsFileVmo
Sourceimpl<___D> Decode<___D> for BootfsFileVmowhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for BootfsFileVmowhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<BootfsFileVmo, ___E> for BootfsFileVmowhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<BootfsFileVmo, ___E> for BootfsFileVmowhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, BootfsFileVmo>
const COPY_OPTIMIZATION: CopyOptimization<Self, BootfsFileVmo>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BootfsFileVmo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BootfsFileVmo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<BootfsFileVmo, ___E> for BootfsFileVmo<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Uint32, ___E>,
T1: Encode<Vmo, ___E>,
impl<___E, T0, T1> Encode<BootfsFileVmo, ___E> for BootfsFileVmo<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Uint32, ___E>,
T1: Encode<Vmo, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BootfsFileVmo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BootfsFileVmo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<BootfsFileVmo> for BootfsFileVmo
impl FromWire<BootfsFileVmo> for BootfsFileVmo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BootfsFileVmo, Self>
const COPY_OPTIMIZATION: CopyOptimization<BootfsFileVmo, Self>
Sourcefn from_wire(wire: BootfsFileVmo) -> Self
fn from_wire(wire: BootfsFileVmo) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for BootfsFileVmo
impl IntoNatural for BootfsFileVmo
Sourcetype Natural = BootfsFileVmo
type Natural = BootfsFileVmo
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for BootfsFileVmo
impl Wire for BootfsFileVmo
Sourcetype Narrowed<'de> = BootfsFileVmo
type Narrowed<'de> = BootfsFileVmo
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.