#[repr(C)]pub struct FactoryItemsGetResponse {
pub payload: OptionalVmo,
pub length: Uint32,
}Expand description
The wire type corresponding to FactoryItemsGetResponse.
Fields
payload: OptionalVmolength: Uint32Trait Implementations
Sourceimpl Constrained for FactoryItemsGetResponse
impl Constrained for FactoryItemsGetResponse
Sourceimpl Debug for FactoryItemsGetResponse
impl Debug for FactoryItemsGetResponse
Sourceimpl<___D> Decode<___D> for FactoryItemsGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for FactoryItemsGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<FactoryItemsGetResponse, ___E> for FactoryItemsGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<FactoryItemsGetResponse, ___E> for FactoryItemsGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, FactoryItemsGetResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, FactoryItemsGetResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FactoryItemsGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FactoryItemsGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<FactoryItemsGetResponse, ___E> for FactoryItemsGetResponse<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalVmo, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<FactoryItemsGetResponse, ___E> for FactoryItemsGetResponse<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalVmo, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FactoryItemsGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FactoryItemsGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<FactoryItemsGetResponse> for FactoryItemsGetResponse
impl FromWire<FactoryItemsGetResponse> for FactoryItemsGetResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<FactoryItemsGetResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<FactoryItemsGetResponse, Self>
Sourcefn from_wire(wire: FactoryItemsGetResponse) -> Self
fn from_wire(wire: FactoryItemsGetResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for FactoryItemsGetResponse
impl IntoNatural for FactoryItemsGetResponse
Sourcetype Natural = FactoryItemsGetResponse
type Natural = FactoryItemsGetResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for FactoryItemsGetResponse
impl Wire for FactoryItemsGetResponse
Sourcetype Narrowed<'de> = FactoryItemsGetResponse
type Narrowed<'de> = FactoryItemsGetResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.