#[repr(C)]pub struct ItemsGet2Request<'de> {
pub type_: Uint32,
pub extra: Box<'de, Extra>,
}Expand description
The wire type corresponding to ItemsGet2Request.
Fields
type_: Uint32extra: Box<'de, Extra>Trait Implementations
Sourceimpl Constrained for ItemsGet2Request<'_>
impl Constrained for ItemsGet2Request<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ItemsGet2Request<'_>>,
_: <ItemsGet2Request<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ItemsGet2Request<'_>>, _: <ItemsGet2Request<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for ItemsGet2Request<'de>
impl<'de> Debug for ItemsGet2Request<'de>
Sourceimpl<'de, ___D> Decode<___D> for ItemsGet2Request<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for ItemsGet2Request<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<___E> Encode<ItemsGet2Request<'static>, ___E> for ItemsGet2Requestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<ItemsGet2Request<'static>, ___E> for ItemsGet2Requestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGet2Request<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGet2Request<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<ItemsGet2Request<'static>, ___E> for &'a ItemsGet2Requestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<ItemsGet2Request<'static>, ___E> for &'a ItemsGet2Requestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGet2Request<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGet2Request<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<ItemsGet2Request<'static>, ___E> for ItemsGet2Request<T0, T1>
impl<___E, T0, T1> Encode<ItemsGet2Request<'static>, ___E> for ItemsGet2Request<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGet2Request<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGet2Request<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<ItemsGet2Request<'de>> for ItemsGet2Request
impl<'de> FromWire<ItemsGet2Request<'de>> for ItemsGet2Request
Sourcefn from_wire(wire: ItemsGet2Request<'de>) -> ItemsGet2Request
fn from_wire(wire: ItemsGet2Request<'de>) -> ItemsGet2Request
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ItemsGet2Request<'de>> for ItemsGet2Request
impl<'de> FromWireRef<ItemsGet2Request<'de>> for ItemsGet2Request
Sourcefn from_wire_ref(wire: &ItemsGet2Request<'de>) -> ItemsGet2Request
fn from_wire_ref(wire: &ItemsGet2Request<'de>) -> ItemsGet2Request
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for ItemsGet2Request<'de>
impl<'de> IntoNatural for ItemsGet2Request<'de>
Sourcetype Natural = ItemsGet2Request
type Natural = ItemsGet2Request
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ItemsGet2Request<'static>
impl Wire for ItemsGet2Request<'static>
Sourcetype Narrowed<'de> = ItemsGet2Request<'de>
type Narrowed<'de> = ItemsGet2Request<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ItemsGet2Request<'static>>)
fn zero_padding(out_: &mut MaybeUninit<ItemsGet2Request<'static>>)
Writes zeroes to the padding for this type, if any.