#[repr(C)]pub struct ItemsGetResponse {
pub payload: OptionalVmo,
pub length: Uint32,
}Expand description
The wire type corresponding to ItemsGetResponse.
Fields
payload: OptionalVmolength: Uint32Trait Implementations
Sourceimpl Constrained for ItemsGetResponse
impl Constrained for ItemsGetResponse
Sourceimpl Debug for ItemsGetResponse
impl Debug for ItemsGetResponse
Sourceimpl<___D> Decode<___D> for ItemsGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ItemsGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ItemsGetResponse, ___E> for ItemsGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ItemsGetResponse, ___E> for ItemsGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ItemsGetResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ItemsGetResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<ItemsGetResponse, ___E> for ItemsGetResponse<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalVmo, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<ItemsGetResponse, ___E> for ItemsGetResponse<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalVmo, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ItemsGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ItemsGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ItemsGetResponse> for ItemsGetResponse
impl FromWire<ItemsGetResponse> for ItemsGetResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ItemsGetResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ItemsGetResponse, Self>
Sourcefn from_wire(wire: ItemsGetResponse) -> Self
fn from_wire(wire: ItemsGetResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ItemsGetResponse
impl IntoNatural for ItemsGetResponse
Sourcetype Natural = ItemsGetResponse
type Natural = ItemsGetResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ItemsGetResponse
impl Wire for ItemsGetResponse
Sourcetype Narrowed<'de> = ItemsGetResponse
type Narrowed<'de> = ItemsGetResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.