#[repr(C)]pub struct ReadOnlyLogGetResponse {
pub log: DebugLog,
}Expand description
The wire type corresponding to ReadOnlyLogGetResponse.
Fields
log: DebugLogTrait Implementations
Sourceimpl Constrained for ReadOnlyLogGetResponse
impl Constrained for ReadOnlyLogGetResponse
Sourceimpl Debug for ReadOnlyLogGetResponse
impl Debug for ReadOnlyLogGetResponse
Sourceimpl<___D> Decode<___D> for ReadOnlyLogGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ReadOnlyLogGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ReadOnlyLogGetResponse, ___E> for ReadOnlyLogGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ReadOnlyLogGetResponse, ___E> for ReadOnlyLogGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ReadOnlyLogGetResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ReadOnlyLogGetResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ReadOnlyLogGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ReadOnlyLogGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ReadOnlyLogGetResponse, ___E> for ReadOnlyLogGetResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<DebugLog, ___E>,
impl<___E, T0> Encode<ReadOnlyLogGetResponse, ___E> for ReadOnlyLogGetResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<DebugLog, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ReadOnlyLogGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ReadOnlyLogGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ReadOnlyLogGetResponse> for ReadOnlyLogGetResponse
impl FromWire<ReadOnlyLogGetResponse> for ReadOnlyLogGetResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ReadOnlyLogGetResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ReadOnlyLogGetResponse, Self>
Sourcefn from_wire(wire: ReadOnlyLogGetResponse) -> Self
fn from_wire(wire: ReadOnlyLogGetResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ReadOnlyLogGetResponse
impl IntoNatural for ReadOnlyLogGetResponse
Sourcetype Natural = ReadOnlyLogGetResponse
type Natural = ReadOnlyLogGetResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ReadOnlyLogGetResponse
impl Wire for ReadOnlyLogGetResponse
Sourcetype Narrowed<'de> = ReadOnlyLogGetResponse
type Narrowed<'de> = ReadOnlyLogGetResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.