#[repr(C)]pub struct RetrievedItems {
pub payload: Vmo,
pub length: Uint32,
pub extra: Uint32,
}Expand description
The wire type corresponding to RetrievedItems.
Fields
payload: Vmolength: Uint32extra: Uint32Trait Implementations
Sourceimpl Constrained for RetrievedItems
impl Constrained for RetrievedItems
Sourceimpl Debug for RetrievedItems
impl Debug for RetrievedItems
Sourceimpl<___D> Decode<___D> for RetrievedItemswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for RetrievedItemswhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<RetrievedItems, ___E> for RetrievedItemswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<RetrievedItems, ___E> for RetrievedItemswhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, RetrievedItems>
const COPY_OPTIMIZATION: CopyOptimization<Self, RetrievedItems>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RetrievedItems>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RetrievedItems>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2> Encode<RetrievedItems, ___E> for RetrievedItems<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Vmo, ___E>,
T1: Encode<Uint32, ___E>,
T2: Encode<Uint32, ___E>,
impl<___E, T0, T1, T2> Encode<RetrievedItems, ___E> for RetrievedItems<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Vmo, ___E>,
T1: Encode<Uint32, ___E>,
T2: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RetrievedItems>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RetrievedItems>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<RetrievedItems> for RetrievedItems
impl FromWire<RetrievedItems> for RetrievedItems
Sourceconst COPY_OPTIMIZATION: CopyOptimization<RetrievedItems, Self>
const COPY_OPTIMIZATION: CopyOptimization<RetrievedItems, Self>
Sourcefn from_wire(wire: RetrievedItems) -> Self
fn from_wire(wire: RetrievedItems) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for RetrievedItems
impl IntoNatural for RetrievedItems
Sourcetype Natural = RetrievedItems
type Natural = RetrievedItems
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for RetrievedItems
impl Wire for RetrievedItems
Sourcetype Narrowed<'de> = RetrievedItems
type Narrowed<'de> = RetrievedItems
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.