#[repr(C)]pub struct SvcStashProviderGetResponse {
pub resource: ServerEnd<SvcStash, Channel>,
}Expand description
The wire type corresponding to SvcStashProviderGetResponse.
Fields
resource: ServerEnd<SvcStash, Channel>Trait Implementations
Sourceimpl Constrained for SvcStashProviderGetResponse
impl Constrained for SvcStashProviderGetResponse
Sourceimpl Debug for SvcStashProviderGetResponse
impl Debug for SvcStashProviderGetResponse
Sourceimpl<___D> Decode<___D> for SvcStashProviderGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for SvcStashProviderGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<SvcStashProviderGetResponse, ___E> for SvcStashProviderGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SvcStashProviderGetResponse, ___E> for SvcStashProviderGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SvcStashProviderGetResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, SvcStashProviderGetResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SvcStashProviderGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SvcStashProviderGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SvcStashProviderGetResponse, ___E> for SvcStashProviderGetResponse<T0>
impl<___E, T0> Encode<SvcStashProviderGetResponse, ___E> for SvcStashProviderGetResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SvcStashProviderGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SvcStashProviderGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SvcStashProviderGetResponse> for SvcStashProviderGetResponse
impl FromWire<SvcStashProviderGetResponse> for SvcStashProviderGetResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SvcStashProviderGetResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<SvcStashProviderGetResponse, Self>
Sourcefn from_wire(wire: SvcStashProviderGetResponse) -> Self
fn from_wire(wire: SvcStashProviderGetResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for SvcStashProviderGetResponse
impl IntoNatural for SvcStashProviderGetResponse
Sourcetype Natural = SvcStashProviderGetResponse
type Natural = SvcStashProviderGetResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SvcStashProviderGetResponse
impl Wire for SvcStashProviderGetResponse
Sourcetype Narrowed<'de> = SvcStashProviderGetResponse
type Narrowed<'de> = SvcStashProviderGetResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.