#[repr(C)]pub struct SvcStashStoreRequest {
pub svc_endpoint: ServerEnd<Directory, Channel>,
}Expand description
The wire type corresponding to SvcStashStoreRequest.
Fields
svc_endpoint: ServerEnd<Directory, Channel>Trait Implementations
Sourceimpl Constrained for SvcStashStoreRequest
impl Constrained for SvcStashStoreRequest
Sourceimpl Debug for SvcStashStoreRequest
impl Debug for SvcStashStoreRequest
Sourceimpl<___D> Decode<___D> for SvcStashStoreRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for SvcStashStoreRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<SvcStashStoreRequest, ___E> for SvcStashStoreRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<SvcStashStoreRequest, ___E> for SvcStashStoreRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SvcStashStoreRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, SvcStashStoreRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SvcStashStoreRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SvcStashStoreRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SvcStashStoreRequest, ___E> for SvcStashStoreRequest<T0>
impl<___E, T0> Encode<SvcStashStoreRequest, ___E> for SvcStashStoreRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SvcStashStoreRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SvcStashStoreRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SvcStashStoreRequest> for SvcStashStoreRequest
impl FromWire<SvcStashStoreRequest> for SvcStashStoreRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SvcStashStoreRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<SvcStashStoreRequest, Self>
Sourcefn from_wire(wire: SvcStashStoreRequest) -> Self
fn from_wire(wire: SvcStashStoreRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for SvcStashStoreRequest
impl IntoNatural for SvcStashStoreRequest
Sourcetype Natural = SvcStashStoreRequest
type Natural = SvcStashStoreRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SvcStashStoreRequest
impl Wire for SvcStashStoreRequest
Sourcetype Narrowed<'de> = SvcStashStoreRequest
type Narrowed<'de> = SvcStashStoreRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.