#[repr(C)]pub struct UserbootPostStashSvcRequest {
pub stash_svc_endpoint: ServerEnd<SvcStash, Channel>,
}Expand description
The wire type corresponding to UserbootPostStashSvcRequest.
Fields
stash_svc_endpoint: ServerEnd<SvcStash, Channel>Trait Implementations
Sourceimpl Constrained for UserbootPostStashSvcRequest
impl Constrained for UserbootPostStashSvcRequest
Sourceimpl Debug for UserbootPostStashSvcRequest
impl Debug for UserbootPostStashSvcRequest
Sourceimpl<___D> Decode<___D> for UserbootPostStashSvcRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for UserbootPostStashSvcRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<UserbootPostStashSvcRequest, ___E> for UserbootPostStashSvcRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<UserbootPostStashSvcRequest, ___E> for UserbootPostStashSvcRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, UserbootPostStashSvcRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, UserbootPostStashSvcRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UserbootPostStashSvcRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UserbootPostStashSvcRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<UserbootPostStashSvcRequest, ___E> for UserbootPostStashSvcRequest<T0>
impl<___E, T0> Encode<UserbootPostStashSvcRequest, ___E> for UserbootPostStashSvcRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UserbootPostStashSvcRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UserbootPostStashSvcRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<UserbootPostStashSvcRequest> for UserbootPostStashSvcRequest
impl FromWire<UserbootPostStashSvcRequest> for UserbootPostStashSvcRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<UserbootPostStashSvcRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<UserbootPostStashSvcRequest, Self>
Sourcefn from_wire(wire: UserbootPostStashSvcRequest) -> Self
fn from_wire(wire: UserbootPostStashSvcRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for UserbootPostStashSvcRequest
impl IntoNatural for UserbootPostStashSvcRequest
Sourcetype Natural = UserbootPostStashSvcRequest
type Natural = UserbootPostStashSvcRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for UserbootPostStashSvcRequest
impl Wire for UserbootPostStashSvcRequest
Sourcetype Narrowed<'de> = UserbootPostStashSvcRequest
type Narrowed<'de> = UserbootPostStashSvcRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.