#[repr(C)]pub struct WriteOnlyLogGetResponse {
pub log: DebugLog,
}Expand description
The wire type corresponding to WriteOnlyLogGetResponse.
Fields
log: DebugLogTrait Implementations
Sourceimpl Constrained for WriteOnlyLogGetResponse
impl Constrained for WriteOnlyLogGetResponse
Sourceimpl Debug for WriteOnlyLogGetResponse
impl Debug for WriteOnlyLogGetResponse
Sourceimpl<___D> Decode<___D> for WriteOnlyLogGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for WriteOnlyLogGetResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<WriteOnlyLogGetResponse, ___E> for WriteOnlyLogGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<WriteOnlyLogGetResponse, ___E> for WriteOnlyLogGetResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, WriteOnlyLogGetResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, WriteOnlyLogGetResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WriteOnlyLogGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WriteOnlyLogGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<WriteOnlyLogGetResponse, ___E> for WriteOnlyLogGetResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<DebugLog, ___E>,
impl<___E, T0> Encode<WriteOnlyLogGetResponse, ___E> for WriteOnlyLogGetResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<DebugLog, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WriteOnlyLogGetResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WriteOnlyLogGetResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<WriteOnlyLogGetResponse> for WriteOnlyLogGetResponse
impl FromWire<WriteOnlyLogGetResponse> for WriteOnlyLogGetResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WriteOnlyLogGetResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<WriteOnlyLogGetResponse, Self>
Sourcefn from_wire(wire: WriteOnlyLogGetResponse) -> Self
fn from_wire(wire: WriteOnlyLogGetResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for WriteOnlyLogGetResponse
impl IntoNatural for WriteOnlyLogGetResponse
Sourcetype Natural = WriteOnlyLogGetResponse
type Natural = WriteOnlyLogGetResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for WriteOnlyLogGetResponse
impl Wire for WriteOnlyLogGetResponse
Sourcetype Narrowed<'de> = WriteOnlyLogGetResponse
type Narrowed<'de> = WriteOnlyLogGetResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.